@@ -41,6 +41,10 @@ class Session(e3.Session):
             style)
         self.add_action(e3.Action.ACTION_SEND_MESSAGE, (cid, message))
 
+    def send_typing_notification(self, cid):
+        '''send typing notification to contact'''
+        pass
+
     def request_attention(self, cid):
         '''request the attention of the contact'''
         account = self.account.account
@@ -48,4 +52,17 @@ class Session(e3.Session):
             '%s requests your attention' % (account, ), account)
         self.add_action(e3.Action.ACTION_SEND_MESSAGE, (cid, message))
 
+    def session_has_service(self, service):
+        '''returns True if some service is supported, False otherwise'''
+        if service in [Session.SERVICE_CONTACT_MANAGING,
+                        Session.SERVICE_CONTACT_BLOCK,
+                        Session.SERVICE_CONTACT_ALIAS,
+                        Session.SERVICE_GROUP_MANAGING,
+                        Session.SERVICE_CONTACT_INVITE,
+                        Session.SERVICE_CALLS,
+                        Session.SERVICE_FILETRANSFER]:
+            return False
+
+        return True
+
 extension.implements(Session, 'session')
