@@ -255,11 +255,6 @@ class Worker(e3.Worker):
         self.session.picture_change_succeed(self.session.account.account,
                 picture_name)
 
-    def _handle_action_set_preferences(self, preferences):
-        '''handle Action.ACTION_SET_PREFERENCES
-        '''
-        pass
-
     def _handle_action_new_conversation(self, account, cid):
         '''handle Action.ACTION_NEW_CONVERSATION
         '''
