@@ -119,7 +119,7 @@ class Worker(e3.Worker):
         show = presence.getShow()
         account = presence.getFrom().getStripped()
 
-        if show == None:
+        if show is None:
             show = presence.getAttrs().get('type', 'chat')
 
         stat = STATUS_MAP_REVERSE.get(show, e3.status.ONLINE)
@@ -249,7 +249,6 @@ class Worker(e3.Worker):
         log.debug('closing thread')
         self.session.events.queue.clear()
         self.session.logger.quit()
-        self.client.disconnect()
         self._continue = False
         self.session.disconnected(None, False)
 
@@ -299,7 +298,7 @@ class Worker(e3.Worker):
             return
 
         if self.client.auth(self.jid.getNode(),
-            self.session.account.password) == None:
+            self.session.account.password) is None:
             self.session.login_failed('Authentication error')
             return
         
@@ -388,6 +387,10 @@ class Worker(e3.Worker):
         self.client.send(xmpp.protocol.Presence(priority=24, show=stat,
             status=message))
 
+        if not self.session.facebook_client is None and self.session.config.b_fb_status_write:
+            ##update facebook message
+            self.session.facebook_client.message = message
+
         e3.base.Worker._handle_action_set_message(self, message)
 
     def _handle_action_set_media(self, message):
@@ -431,22 +434,20 @@ class Worker(e3.Worker):
         self.client.send(iq_vcard)
 
         avatar_hash = hashlib.sha1(avatar).hexdigest().encode("hex")
-        avatar_path = os.path.join(self.my_avatars.path, avatar_hash)
 
         if avatar_hash in self.my_avatars:
+            avatar_path = os.path.join(self.my_avatars.path, avatar_hash)
             self.session.picture_change_succeed(self.session.account.account,
                     avatar_path)
+            self.session.contacts.me.picture = avatar_path
         else:
-            self.my_avatars.insert_raw(avatar_data)
-            self.session.picture_change_succeed(self.session.account.account,
-                    avatar_path)
-
-        self.session.contacts.me.picture = avatar_path
-
-    def _handle_action_set_preferences(self, preferences):
-        '''handle Action.ACTION_SET_PREFERENCES
-        '''
-        pass
+            result = self.my_avatars.insert_raw(StringIO.StringIO(avatar_data))
+            if not result is None:
+                avatar_hash = result[1]
+                avatar_path = os.path.join(self.my_avatars.path, avatar_hash)
+                self.session.picture_change_succeed(self.session.account.account,
+                        avatar_path)
+                self.session.contacts.me.picture = avatar_path
 
     def _handle_action_new_conversation(self, account, cid):
         '''handle Action.ACTION_NEW_CONVERSATION
