@@ -71,6 +71,12 @@ class Session(e3.Session):
             style)
         self.add_action(e3.Action.ACTION_SEND_MESSAGE, (cid, message, cedict, celist))
 
+    def send_typing_notification(self, cid):
+        '''send typing notification to contact'''
+        account = self.account.account
+        message = e3.Message(e3.Message.TYPE_TYPING, None, account)
+        self.add_action(e3.Action.ACTION_SEND_MESSAGE, (cid, message))
+
     def request_attention(self, cid):
         '''request the attention of the contact'''
         account = self.account.account
@@ -144,3 +150,10 @@ class Session(e3.Session):
             return False
             
         return (Membership.FORWARD & contacts[0].memberships)
+
+    def session_has_service(self, service):
+        '''returns True if some service is supported, False otherwise'''
+        #papyon support ALL services
+        if service == Session.SERVICE_CALLS:
+            return False
+        return True
