@@ -1238,11 +1238,6 @@ class Worker(e3.base.Worker, papyon.Client):
             self.content_roaming.store(xml.sax.saxutils.escape(nick),
                     xml.sax.saxutils.escape(message), avatar)
 
-    def _handle_action_set_preferences(self, preferences):
-        '''handle Action.ACTION_SET_PREFERENCES
-        '''
-        pass
-
     def _handle_action_new_conversation(self, account, cid):
         ''' handle Action.ACTION_NEW_CONVERSATION '''
         # % { 'ci' : cid, 'acco' : account }
@@ -1335,7 +1330,8 @@ class Worker(e3.base.Worker, papyon.Client):
                 if switchboard is None or \
                    switchboard.state == papyon.msnp.ProtocolState.CLOSED:
 
-                    if message.type == e3.base.Message.TYPE_NUDGE:
+                    if message.type == e3.base.Message.TYPE_NUDGE or \
+                       message.type == e3.base.Message.TYPE_TYPING:
                         return
                     else:
                         self.oim_box.send_message(first_dude, message.body)
@@ -1345,6 +1341,9 @@ class Worker(e3.base.Worker, papyon.Client):
         if message.type == e3.base.Message.TYPE_NUDGE:
             papyconversation.send_nudge()
 
+        elif message.type == e3.base.Message.TYPE_TYPING:
+            papyconversation.send_typing_notification()
+
         elif message.type == e3.base.Message.TYPE_MESSAGE:
             # format the text for papy
             formatting = formatting_e3_to_papy(message.style)
@@ -1474,4 +1473,3 @@ class Worker(e3.base.Worker, papyon.Client):
 
         del self.calls[self.rcalls[c]]
         del self.rcalls[c]
-
