@@ -56,14 +56,40 @@ def project_path():
 
 os.chdir(os.path.abspath(project_path()))
 
-import gettext
+
 # load translations
+import gettext
+import locale
+default_locale = locale.getdefaultlocale()[0]
+lang = os.getenv('LANGUAGE') or default_locale
+translation = gettext.NullTranslations()
+locales_path = 'po/' if os.path.exists('po/') else None
+
 if os.path.exists('default.mo'):
-    gettext.GNUTranslations(open('default.mo')).install()
-elif os.path.exists('po/'):
-    gettext.install('emesene', 'po/')
+    translation = gettext.GNUTranslations(open('default.mo'))
 else:
-    gettext.install('emesene')
+    try:
+        #try with LANGUAGE variable
+        translation = gettext.translation('emesene', localedir=locales_path, \
+                                          languages=[lang])
+    except IOError:
+        try:
+            #try with Python's locale module
+            translation = gettext.translation('emesene', \
+                                              localedir=locales_path, \
+                                              languages=[default_locale])
+        except IOError:
+            #let gettext handle the language
+            try:
+                translation = gettext.translation('emesene', \
+                                              localedir=locales_path)
+            except IOError:
+                pass
+    except AttributeError:
+        pass
+
+translation.install()
+
 
 import glib
 import optparse
@@ -214,17 +240,24 @@ class Controller(object):
 
         debugger.init(debuglevel=options.debuglevel)
 
-        if options.single_instance:
-            try:
-                import SingleInstance
-                self.single_instance = SingleInstance.SingleInstance()
-                if self.single_instance.emesene_is_running():
+        #needed to check for autologin
+        self.emesene_is_running = False
+        try:
+            if os.name == 'posix':
+                from SingleInstance import SingleInstancePosix as SingleInstance
+            else:
+                from SingleInstance import SingleInstanceWin32 as SingleInstance
+
+            self.single_instance = SingleInstance()
+            if self.single_instance.emesene_is_running():
+                self.emesene_is_running = True
+                # try to show the instance that's already running
+                if options.single_instance:
                     print "Another instance of emesene is already running."
-                    # try to show the instance that's already running
                     self.single_instance.show()
                     sys.exit(0)
-            except ImportError:
-                pass
+        except ImportError:
+            pass
 
         if options.minimized:
             self.minimize = True
@@ -239,7 +272,9 @@ class Controller(object):
 
         proxy = self._get_proxy_settings()
         use_http = self.config.get_or_set('b_use_http', False)
-        self.go_login(proxy, use_http)
+
+        #cancel autologin if another emesene instance is running
+        self.go_login(proxy, use_http, no_autologin=self.emesene_is_running)
 
         if self.minimize:
             self.window.iconify()
@@ -293,15 +328,14 @@ class Controller(object):
     def _restore_session(self):
         account = self.session.account
         if self.conv_manager_available:
+            self.session.conversation_managers = []
             if account and self.last_session_account == account.account and \
                self.last_session_service == account.service:
                 self.conv_manager_available = False
                 self.session.conversations = {}
                 for conv_manager in self.conversations:
                     conv_manager.renew_session(self.session)
-                self.tray_icon.set_conversations(self.conversations)
-                if self.unity_launcher is not None:
-                    self.unity_launcher.set_conversations(self.conversations)
+                    self.session.conversation_managers.append(conv_manager)
             else:
                 for conv_manager in self.conversations:
                     conv_manager.hide_all()
@@ -695,6 +729,7 @@ class Controller(object):
                 self._set_location(window, True)
                 conv_manager = window.content
                 self.conversations.append(conv_manager)
+                self.session.conversation_managers.append(conv_manager)
 
                 if self.session.config.b_conv_minimized and other_started:
                     window.iconify()
@@ -706,11 +741,6 @@ class Controller(object):
             else:
                 conv_manager = self.conversations[0]
 
-
-        self.tray_icon.set_conversations(self.conversations)
-        if self.unity_launcher is not None:
-            self.unity_launcher.set_conversations(self.conversations)
-
         conversation = conv_manager.new_conversation(cid, members)
 
         conversation.update_data()
@@ -748,6 +778,7 @@ class Controller(object):
                 self.session.config.b_conv_maximized = False
             else:
                 self.session.config.b_conv_maximized = True
+            self.session.conversation_managers.remove(conv_manager)
 
         conv_manager.close_all()
         self.conversations.remove(conv_manager)
