@@ -169,16 +169,16 @@ class Category(object):
         if system_default:
             self.system_default = system_default
 
-        if interfaces is None:
-            self.interfaces = ()
-        else:
-            self.interfaces = tuple(interfaces)
+        self.interfaces = ()
 
         # id: class
         self.classes = {}
         # class: id
         self.ids = {}
 
+        if interfaces is not None:
+            self.set_interface(interfaces)
+
         self.is_single = single_instance
         self.multi_extension = False
         self.instance = None #a weakref to the saved (single)instance
@@ -398,6 +398,13 @@ def get_categories():
     '''return a dict with all the categories'''
     return _categories
 
+def get_multiextension_categories():
+    ''' get available categories'''
+    categories_blacklisted = ['option provider', 'session']
+    categories = [ctg for ctg in get_categories().keys()
+                    if len(get_extensions(ctg)) > 1 and not ctg in categories_blacklisted]
+    categories.sort()
+    return categories
 
 def get_extensions(category_name):
     '''return a dict of the available extensions id:class'''
