@@ -44,8 +44,8 @@ EMESENE_LICENSE = '''    emesene is free software; you can redistribute it and/o
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 '''
 
-EMESENE_VERSION = "2.12.1"
-EMESENE_LAST_STABLE = "2.12.1"
+EMESENE_VERSION = "2.12.3"
+EMESENE_LAST_STABLE = "2.12.3"
 EMESENE_WEBSITE = "http://www.emesene.org"
 EMESENE_AUTHORS = "marianoguerra & c10ud"
 EMESENE_CONTRIBUTORS = [ # TODO: Load this from CONTRIBUTORS
@@ -67,12 +67,12 @@ class MenuHandler(object):
     menu items
     '''
 
-    def __init__(self, session, dialog, contact_list):
+    def __init__(self, session, contact_list):
         '''constructor'''
         self.file_handler = FileHandler(session)
-        self.actions_handler = ActionsHandler(session, dialog, contact_list)
+        self.actions_handler = ActionsHandler(session, contact_list)
         self.options_handler = OptionsHandler(session, contact_list)
-        self.help_handler = HelpHandler(dialog)
+        self.help_handler = HelpHandler()
 
 class FileHandler(object):
     '''this handler contains all the handlers needed to handle the file
@@ -104,11 +104,11 @@ class ActionsHandler(object):
     menu items
     '''
 
-    def __init__(self, session, dialog, contact_list):
+    def __init__(self, session, contact_list):
         '''constructor'''
-        self.contact_handler = ContactHandler(session, dialog, contact_list)
-        self.group_handler = GroupHandler(session, dialog, contact_list)
-        self.my_account_handler = MyAccountHandler(session, dialog)
+        self.contact_handler = ContactHandler(session, contact_list)
+        self.group_handler = GroupHandler(session, contact_list)
+        self.my_account_handler = MyAccountHandler(session)
 
 class OptionsHandler(object):
     '''this handler contains all the handlers needed to handle the options
@@ -171,9 +171,9 @@ class HelpHandler(object):
     menu items
     '''
 
-    def __init__(self, dialog):
+    def __init__(self):
         '''constructor'''
-        self.dialog = dialog
+        self.dialog = extension.get_default('dialog')
         self.debug_window = None
 
     def on_about_selected(self):
@@ -236,10 +236,10 @@ class ContactHandler(object):
     menu items
     '''
 
-    def __init__(self, session, dialog, contact_list):
+    def __init__(self, session, contact_list):
         '''constructor'''
         self.session = session
-        self.dialog = dialog
+        self.dialog = extension.get_default('dialog')
         self.contact_list = contact_list
 
     def get_contact_groups(self):
@@ -370,10 +370,10 @@ class GroupHandler(object):
     menu items
     '''
 
-    def __init__(self, session, dialog, contact_list):
+    def __init__(self, session, contact_list):
         '''constructor'''
         self.session = session
-        self.dialog = dialog
+        self.dialog = extension.get_default('dialog')
         self.contact_list = contact_list
 
     def is_by_group_view(self):
@@ -461,10 +461,10 @@ class MyAccountHandler(object):
     menu items
     '''
 
-    def __init__(self, session, dialog):
+    def __init__(self, session):
         '''constructor'''
         self.session = session
-        self.dialog = dialog
+        self.dialog = extension.get_default('dialog')
 
         self.old_nick = self.session.contacts.me.nick
         self.old_pm = self.session.contacts.me.message
@@ -492,24 +492,16 @@ class ConversationToolbarHandler(object):
     '''this handler contains all the methods to handle a conversation toolbar
     '''
 
-    def __init__(self, session, dialog, theme, conversation):
+    def __init__(self, session, theme, conversation):
         '''constructor'''
         self.session = session
-        self.dialog = dialog
+        self.dialog = extension.get_default('dialog')
         self.conversation = conversation
         self.theme = theme
 
-    def session_call_supported(self):
-        '''check if current session supports calls '''
-        user = self.session.account.account
-        current_service = self.session.config.d_user_service.get(user, 'msn')
-        return current_service in ['']
-
-    def session_filetransfer_supported(self):
-        '''check if current session supports file transfers '''
-        user = self.session.account.account
-        current_service = self.session.config.d_user_service.get(user, 'msn')
-        return current_service in ['msn']
+    def session_service_supported(self, service):
+        '''check if current session supports the service '''
+        return self.session.session_has_service(service)
 
     def on_font_selected(self):
         '''called when the Font button is selected'''
@@ -574,6 +566,22 @@ class ConversationToolbarHandler(object):
         '''called when the user is requesting an audio-video call'''
         self.conversation.on_av_call()
 
+class OutputViewHandler(object):
+    '''this handler contains all the methods to handle output view
+    '''
+
+    def __init__(self, conversation):
+        '''constructor'''
+        self.conversation = conversation
+
+    def on_clean_selected(self):
+        '''called when the Clear menu item is selected'''
+        self.conversation.on_clean()
+
+    def add_emoticon_selected(self, uri):
+        '''called when an emoticon is being stolen'''
+        self.conversation.steal_emoticon(uri)
+
 class TrayIconHandler(FileHandler):
     """
     this handler contains all the methods to handle a tray icon
@@ -590,11 +598,21 @@ class TrayIconHandler(FileHandler):
         self.theme = theme
         
     def on_hide_show_mainwindow(self, main_window=None):
-        if (main_window != None):
-            if(main_window.get_property("visible")):
+        if main_window is not None:
+            if main_window.get_visible():
                 main_window.hide()
             else:
-                main_window.show()
+                main_window.present()
+                
+    def on_preferences_selected(self):
+        '''called when the preference button is selected'''
+        instance = extension.get_and_instantiate('preferences', self.session)
+        if self.session is not instance.session:
+            instance.remove_subscriptions()
+            extension.delete_instance('preferences')
+            instance = extension.get_and_instantiate('preferences', self.session)
+        instance.show()
+        instance.present()
 
 class FileTransferHandler(object):
     ''' this handler handles a file transfer object '''
