@@ -22,6 +22,7 @@ import gtk
 import time
 
 import extension
+import e3
 from e3 import status
 
 import gui
@@ -52,7 +53,6 @@ class TrayIcon(gtk.StatusIcon, gui.BaseTray):
         self.connect('popup-menu', self._on_popup)
 
         self.set_login()
-        gui.BaseTray.set_visible(self, True)
         gtk.StatusIcon.set_visible(self, True)
 
         self.set_tooltip("emesene")
@@ -80,7 +80,7 @@ class TrayIcon(gtk.StatusIcon, gui.BaseTray):
         Blink tray icon and save newest unread message
         """
 
-        conv_manager = self._get_conversation_manager(cid, account)
+        conv_manager = self.handler.session.get_conversation_manager(cid, [account])
 
         if conv_manager and not conv_manager.is_active():
             self.set_blinking(True)
@@ -102,10 +102,10 @@ class TrayIcon(gtk.StatusIcon, gui.BaseTray):
         if self.last_new_message is not None and self.get_blinking():
             # show the tab with the latest message
             cid = self.last_new_message
-            conv_manager = self._get_conversation_manager(cid)
+            conv_manager = self.handler.session.get_conversation_manager(cid)
 
             if conv_manager:
-                conversation = conv_manager.conversations[cid]
+                conversation = conv_manager.has_similar_conversation(cid)
                 conv_manager.present(conversation)
         else:
             self.handler.on_hide_show_mainwindow(self.main_window)
@@ -195,6 +195,9 @@ class MainMenu(gtk.Menu):
         self.quit = gtk.ImageMenuItem(gtk.STOCK_QUIT)
         self.quit.connect('activate',
             lambda *args: self.handler.on_quit_selected())
+        self.preferences = gtk.ImageMenuItem(gtk.STOCK_PREFERENCES)
+        self.preferences.connect('activate',
+            lambda *args: self.handler.on_preferences_selected())
 
         self.unmute_label = _('Unmute sounds')
         self.unmute_stock = gtk.STOCK_MEDIA_PLAY
@@ -209,9 +212,11 @@ class MainMenu(gtk.Menu):
 
         self.append(self.hide_show_mainwindow)
         self.append(self.mute)
-        self.append(self.status)
+        if self.handler.session.session_has_service(e3.Session.SERVICE_STATUS):
+            self.append(self.status)
         self.append(self.list)
         self.append(self.disconnect)
+        self.append(self.preferences)
         self.append(gtk.SeparatorMenuItem())
         self.append(self.quit)
 
