@@ -17,6 +17,7 @@
 #    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 import gtk
+import gobject
 import logging
 log = logging.getLogger('gtkui.AdiumTextBox')
 import webkit
@@ -32,15 +33,15 @@ class OutputView(webkit.WebView):
     '''a class that represents the output widget of a conversation
     '''
 
-    def __init__(self, theme, add_emoticon_cb):
+    def __init__(self, theme, handler):
         webkit.WebView.__init__(self)
         settings = self.get_settings()
         settings.set_property('default-font-size', 8)
 
+        self.handler = handler
         self.theme = theme
         self.ready = False
         self.pending = []
-        self.add_emoticon_cb = add_emoticon_cb
         self.connect('load-finished', self._loading_finished_cb)
         self.connect('populate-popup', self.on_populate_popup)
         self.connect('navigation-requested', self.on_navigation_requested)
@@ -114,22 +115,29 @@ class OutputView(webkit.WebView):
 
         select_all_item = gtk.MenuItem(label=_("Select All"))
         select_all_item.connect('activate', lambda *args: self.select_all())
-        clear_item = gtk.MenuItem(label=_("Clear"))
-        clear_item.connect('activate', self.clear)
         menu.append(select_all_item)
-        menu.append(clear_item)
+
+        if self.handler is not None:
+            clear_item = gtk.MenuItem(label=_("Clear"))
+            clear_item.connect('activate',  lambda *args: self.handler.on_clean_selected())
+            menu.append(clear_item)
+
         menu.show_all()
 
     def on_download_requested(self, webview, download):
-        if self.add_emoticon_cb is not None:
+        if self.handler is not None:
             uri = download.get_uri().split("?")[0]
-            self.add_emoticon_cb(uri)
+            self.handler.add_emoticon_selected(uri)
         return False
 
     def on_navigation_requested(self, widget, WebKitWebFrame, WebKitNetworkRequest):
         '''callback called when a link is clicked'''
         href = WebKitNetworkRequest.get_uri()
 
+        if href.startswith("search://"):
+            self.emit("search_request", href)
+            return True
+
         if not href.startswith("file://"):
             log.info("link clicked: " + href)
             gui.base.Desktop.open(href)
@@ -137,6 +145,9 @@ class OutputView(webkit.WebView):
 
         return False
 
+gobject.type_register(OutputView)
+gobject.signal_new("search_request", OutputView, gobject.SIGNAL_RUN_FIRST,
+                   gobject.TYPE_NONE, (gobject.TYPE_PYOBJECT,))
 
 class OutputText(gtk.ScrolledWindow):
     '''a text box inside a scroll that provides methods to get and set the
@@ -146,7 +157,7 @@ class OutputText(gtk.ScrolledWindow):
     AUTHOR = 'Mariano Guerra'
     WEBSITE = 'www.emesene.org'
 
-    def __init__(self, config, add_emoticon_cb):
+    def __init__(self, config, handler):
         '''constructor'''
         gtk.ScrolledWindow.__init__(self)
 
@@ -156,22 +167,28 @@ class OutputText(gtk.ScrolledWindow):
         self.set_shadow_type(gtk.SHADOW_IN)
         self.loaded = False
 
-        self.view = OutputView(gui.theme.conv_theme, add_emoticon_cb)
+        self.view = OutputView(gui.theme.conv_theme, handler)
+        self.view.connect('search_request', self._search_request_cb)
         self.clear()
         self.view.show()
         self.add(self.view)
-        self.locked = False
+        self.locked = 0
         self.pending = []
 
+    def _search_request_cb(self, view, link):
+        self.emit("search_request", link)
+
     def lock (self):
-        self.locked = True
+        self.locked += 1
 
     def unlock(self):
         #add messages and then unlock
-        for msg in self.pending:
-            self.view.add_message(msg, self.config.b_allow_auto_scroll)
-        self.pending = []
-        self.locked = False
+        self.locked -=1
+        if self.locked <=0:
+            for msg in self.pending:
+                self.view.add_message(msg, self.config.b_allow_auto_scroll)
+            self.pending = []
+            self.locked = 0
 
     def clear(self, source="", target="", target_display="",
             source_img="", target_img=""):
@@ -205,3 +222,7 @@ class OutputText(gtk.ScrolledWindow):
             _id = base64.b64encode(_creator+xml.sax.saxutils.unescape(_friendly)) #see gui/base/MarkupParser.py
             mystr = "var now=new Date();var x=document.images;for(var i=0;i<x.length;i++){if(x[i].name=='%s'){x[i].src='%s?'+now.getTime();}}" % (_id, path)
             self.view.execute_script(mystr)
+
+gobject.type_register(OutputText)
+gobject.signal_new("search_request", OutputText, gobject.SIGNAL_RUN_FIRST,
+                   gobject.TYPE_NONE, (gobject.TYPE_PYOBJECT,))
