@@ -41,12 +41,12 @@ class Conversation(gtk.VBox, gui.Conversation):
         gui.Conversation.__init__(self, session, cid, update_win, members)
         self.set_border_width(2)
 
+        self.typing_timeout = None
         self.tab_label = tab_label
 
         self._header_visible = session.config.b_show_header
         self._image_visible = session.config.b_show_info
         self._toolbar_visible = session.config.b_show_toolbar
-        self.avatar_box_is_hidden = False
 
         self.panel = gtk.VPaned()
 
@@ -60,7 +60,6 @@ class Conversation(gtk.VBox, gui.Conversation):
             'conversation toolbar')
         TransfersBar = extension.get_default('filetransfer pool')
         CallWidget = extension.get_default('call widget')
-        dialog = extension.get_default('dialog')
 
         self.below_conversation = None
         BelowConversation = extension.get_default('below conversation')
@@ -69,13 +68,18 @@ class Conversation(gtk.VBox, gui.Conversation):
 
         self.header = Header(session, members)
         toolbar_handler = gui.base.ConversationToolbarHandler(self.session,
-            dialog, gui.theme, self)
-        self.toolbar = ConversationToolbar(toolbar_handler)
+            gui.theme, self)
+        self.toolbar = ConversationToolbar(toolbar_handler, self.session)
         self.toolbar.set_property('can-focus', False)
-        self.output = OutputText(self.session.config, self.steal_emoticon_cb)
+        outputview_handler = gui.base.OutputViewHandler(self)
+        self.output = OutputText(self.session.config, outputview_handler)
+        if self.session.conversation_start_locked:
+            self.output.lock()
+
         self.output.set_size_request(-1, 30)
         self.input = InputText(self.session, self._on_send_message,
-                self.cycle_history, self.on_drag_data_received)
+                               self.cycle_history, self.on_drag_data_received,
+                               self._send_typing_notification)
         self.output.set_size_request(-1, 25)
         self.input.set_size_request(-1, 25)
         self.info = ContactInfo(self.session, self.members)
@@ -122,21 +126,21 @@ class Conversation(gtk.VBox, gui.Conversation):
                 his_picture = contact.picture or utils.path_to_url(os.path.abspath(gui.theme.image_theme.user))
                 nick = contact.nick
                 display_name = contact.display_name
-                self.set_sensitive(not contact.blocked, False)
+                self.set_sensitive(not contact.blocked, True)
             else:
                 his_picture = utils.path_to_url(os.path.abspath(gui.theme.image_theme.user))
                 nick = ""
                 display_name = ""
             my_picture = self.session.contacts.me.picture or utils.path_to_url(os.path.abspath(gui.theme.image_theme.user))
-            self.output.clear(account, nick, display_name, my_picture, his_picture)
+            self.output.clear(account, nick, display_name, 
+                              my_picture, his_picture)
 
         self._load_style()
-        
         self.subscribe_signals()
 
         self.tab_index = -1 # used to select an existing conversation
 
-    def steal_emoticon_cb(self, path_uri):
+    def steal_emoticon(self, path_uri):
         '''receives the path or the uri for the emoticon to be added'''
         if path_uri.startswith("file://"):
             path_uri = path_uri[7:]
@@ -195,7 +199,7 @@ class Conversation(gtk.VBox, gui.Conversation):
         else:
             self.info.hide()
 
-    def _on_show_avatar_onleft(self,value):
+    def _on_show_avatar_onleft(self, value):
         '''callback called when config.b_avatar_on_left changes'''
         if value:
             self.hbox.reorder_child(self.panel, 1)
@@ -281,11 +285,14 @@ class Conversation(gtk.VBox, gui.Conversation):
 
     def update_tab(self):
         '''update the values of the tab'''
+        self.typing_timeout = None
+
         self.tab_label.set_image(self.icon)
         self.tab_label.set_text(self.text)
 
         if self.show_avatar_in_taskbar:
-            self.update_window(self.text, self.info.his_avatar.filename, self.tab_index)
+            self.update_window(self.text, self.info.his_avatar.filename, 
+                               self.tab_index)
         else:
             self.update_window(self.text, self.icon, self.tab_index)
 
@@ -315,16 +322,15 @@ class Conversation(gtk.VBox, gui.Conversation):
         self.info.update_group(self.members)
         self.update_tab()
 
-    def set_sensitive(self, is_sensitive, toolbar=True):
+    def set_sensitive(self, is_sensitive, force_sensitive_block_button=False):
         """
         used to make the conversation insensitive while the conversation
         is still open while the user is disconnected and to set it back to
-        sensitive when the user is reconnected
+        sensitive when the user is reconnected.
         """
         self.input.set_sensitive(is_sensitive)
-        self.info.set_sensitive(is_sensitive)
-        if toolbar:
-            self.toolbar.set_sensitive(is_sensitive)
+        self.info.set_sensitive(is_sensitive or force_sensitive_block_button)
+        self.toolbar.set_sensitive(is_sensitive, force_sensitive_block_button)
 
     def set_image_visible(self, is_visible):
         """
@@ -375,7 +381,9 @@ class Conversation(gtk.VBox, gui.Conversation):
         """
         if account in self.members:
             self.tab_label.set_image(gui.theme.image_theme.typing)
-            glib.timeout_add_seconds(3, self.update_tab)
+            if self.typing_timeout is not None:
+                glib.source_remove(self.typing_timeout)
+            self.typing_timeout = glib.timeout_add_seconds(3, self.update_tab)
 
     def on_emote(self, emote):
         '''called when an emoticon is selected'''
@@ -391,13 +399,21 @@ class Conversation(gtk.VBox, gui.Conversation):
 
     def on_toggle_avatar(self):
         '''hide or show the avatar bar'''
-        if self.avatar_box_is_hidden:
-            self.toolbar.toggle_avatar.set_stock_id(gtk.STOCK_GO_FORWARD)
-            self.info.show()
+        if not self.session.config.b_show_info:
+            self.toolbar.toggle_avatar.set_tooltip_text(_('Hide avatar'))
         else:
-            self.toolbar.toggle_avatar.set_stock_id(gtk.STOCK_GO_BACK)
-            self.info.hide()
-        self.avatar_box_is_hidden = not self.avatar_box_is_hidden
+            self.toolbar.toggle_avatar.set_tooltip_text(_('Show avatar'))
+            
+        self.info.set_visible(not self.info.get_visible())
+        self.toolbar.toggle_avatar.set_stock_id(self.get_toggle_avatar_icon())
+        self.session.config.b_show_info = not self.session.config.b_show_info
+
+    def get_toggle_avatar_icon(self):
+        current_stock_id = self.toolbar.toggle_avatar.get_stock_id()
+        if current_stock_id == gtk.STOCK_GO_FORWARD:
+            return gtk.STOCK_GO_BACK
+        else:
+            return gtk.STOCK_GO_FORWARD
 
     def _on_avatarsize_changed(self, value):
         self.info._on_avatarsize_changed(value)
@@ -428,6 +444,7 @@ class Conversation(gtk.VBox, gui.Conversation):
             transfer.contact.account)
             msg = gui.Message.from_information(contact, message)
             self.output.information(self.formatter, msg)
+            self.conv_status.post_process_message(msg)
 
     def on_filetransfer_progress(self, transfer):
         ''' called every chunk received '''
@@ -446,6 +463,7 @@ class Conversation(gtk.VBox, gui.Conversation):
             transfer.contact.account)
             msg = gui.Message.from_information(contact, message)
             self.output.information(self.formatter, msg)
+            self.conv_status.post_process_message(msg)
 
     def on_filetransfer_canceled(self, transfer):
         ''' called when a file transfer is canceled '''
@@ -459,6 +477,7 @@ class Conversation(gtk.VBox, gui.Conversation):
             transfer.contact.account)
             msg = gui.Message.from_information(contact, message)
             self.output.information(self.formatter, msg)
+            self.conv_status.post_process_message(msg)
 
     def on_filetransfer_completed(self, transfer):
         ''' called when a file transfer is completed '''
@@ -471,6 +490,7 @@ class Conversation(gtk.VBox, gui.Conversation):
             _('File transfer completed!'), transfer.contact.account)
             msg = gui.Message.from_information(contact, message)
             self.output.information(self.formatter, msg)
+            self.conv_status.post_process_message(msg)
 
     def on_call_invitation(self, call, cid, westart=False):
         '''called when a new call is issued both from us or other party'''
@@ -484,24 +504,28 @@ class Conversation(gtk.VBox, gui.Conversation):
         account = self.members[0]
         self.call_widget.show_all()
         x_other, x_self = self.call_widget.get_xids()
-        self.session.call_invite(self.cid, account, 0, x_other, x_self) # 0 = Video only
+        self.session.call_invite(self.cid, account, 0, 
+                                 x_other, x_self) # 0 = Video only
 
     def on_voice_call(self):
         '''called when the user is requesting an audio-only call'''
         account = self.members[0]
         self.call_widget.show_all()
         x_other, x_self = self.call_widget.get_xids()
-        self.session.call_invite(self.cid, account, 1, x_other, x_self) # 1 = Audio only
+        self.session.call_invite(self.cid, account, 1, 
+                                 x_other, x_self) # 1 = Audio only
 
     def on_av_call(self):
         '''called when the user is requesting an audio-video call'''
         account = self.members[0]
         self.call_widget.show_all()
         x_other, x_self = self.call_widget.get_xids()
-        self.session.call_invite(self.cid, account, 2, x_other, x_self) # 2 = Audio/Video
+        self.session.call_invite(self.cid, account, 2, 
+                                 x_other, x_self) # 2 = Audio/Video
 
-    def on_drag_data_received(self, widget, context, posx, posy,\
-                          selection, info, timestamp):
+    def on_drag_data_received(self, widget, context, 
+                              posx, posy, selection, 
+                              info, timestamp):
         '''called when a file is received by text input widget'''
         uri = selection.data.strip()
         uri_splitted = uri.split()
