@@ -44,9 +44,6 @@ class ConversationManager(gtk.Notebook, gui.ConversationManager):
         #self.set_scrollable(session.config.get_or_set('b_conv_tab_scroll',
         #    True))
 
-        if session.config.get_or_set('b_conv_tab_popup', False):
-            self.popup_enable()
-
         # mozilla tabs are fixed-width, otherwise do the same as emesene-1
         self.mozilla_tabs = session.config.get_or_set('b_conv_tab_mozilla_like', False)
 
@@ -69,24 +66,24 @@ class ConversationManager(gtk.Notebook, gui.ConversationManager):
         '''callback called when i_tab_position changes'''
         self.set_tab_pos(pos=self.get_tab_position())
 
-    def _set_accels(self):
+    def set_accels(self):
         """set the keyboard shortcuts
         """
         accel_group = gtk.AccelGroup()
         self.get_parent().add_accel_group(accel_group)
         self.accel_group = accel_group
-        accel_group.connect_group(gtk.keysyms.Page_Down, \
-                                  gtk.gdk.CONTROL_MASK, gtk.ACCEL_LOCKED, \
+        accel_group.connect_group(gtk.keysyms.Page_Down,
+                                  gtk.gdk.CONTROL_MASK, gtk.ACCEL_LOCKED,
                                   self.on_key_cycle_tabs)
-        accel_group.connect_group(gtk.keysyms.Page_Up, \
-                                  gtk.gdk.CONTROL_MASK, gtk.ACCEL_LOCKED, \
+        accel_group.connect_group(gtk.keysyms.Page_Up,
+                                  gtk.gdk.CONTROL_MASK, gtk.ACCEL_LOCKED,
                                   self.on_key_cycle_tabs)
-        accel_group.connect_group(gtk.keysyms.W, \
-                                  gtk.gdk.CONTROL_MASK, gtk.ACCEL_LOCKED, \
+        accel_group.connect_group(gtk.keysyms.W,
+                                  gtk.gdk.CONTROL_MASK, gtk.ACCEL_LOCKED,
                                   self.on_key_close_tab)
         if self.session.config.get_or_set('b_escape_hotkey', True):
-            accel_group.connect_group(gtk.keysyms.Escape, \
-                                      0, gtk.ACCEL_LOCKED, \
+            accel_group.connect_group(gtk.keysyms.Escape,
+                                      0, gtk.ACCEL_LOCKED,
                                       self.on_key_close_tab)
 
         for i in range(1, 10):
@@ -149,6 +146,8 @@ class ConversationManager(gtk.Notebook, gui.ConversationManager):
             if (is_waiting and not parent.is_active()) or not is_waiting:
                 parent.set_urgency_hint(is_waiting)
                 conversation.message_waiting = is_waiting
+            if (is_waiting and self.get_current_page() != conversation.tab_index):
+                conversation.message_waiting = is_waiting
 
     def _on_focus(self, widget, event):
         '''called when the widget receives the focus'''
@@ -217,6 +216,7 @@ class ConversationManager(gtk.Notebook, gui.ConversationManager):
         label = TabWidget('Connecting', self._on_tab_menu, self._on_tab_close,
             conversation, self.mozilla_tabs)
         label.set_image(gui.theme.image_theme.connect)
+        del conversation.tab_label
         conversation.tab_label = label
         conversation.tab_index = self.append_page_menu(conversation, label)
         self.set_tab_label_packing(conversation, not self.mozilla_tabs, True, gtk.PACK_START)
@@ -228,7 +228,7 @@ class ConversationManager(gtk.Notebook, gui.ConversationManager):
         gui.ConversationManager.after_new_conversation(self, conversation)
          #If has more than one tab show close buttons
         if len(self.conversations) > 2:
-          conversation.tab_label.close.show()
+            conversation.tab_label.close.show()
         elif len(self.conversations) == 2:
             for k, v in self.conversations.items():
                 v.tab_label.close.show()
