@@ -290,11 +290,17 @@ class Dialog(object):
         chooser.set_current_folder(current_path)
         setattr(window, 'chooser', chooser)
         window.hbox.pack_start(chooser)
-        chooser.connect("file-activated", cls.on_file_click_cb, window, response_cb)
-        cls.add_button(window, gtk.STOCK_CANCEL, stock.CANCEL, response_cb,
-            cls.chooser_cb)
-        cls.add_button(window, gtk.STOCK_OPEN, stock.OPEN, response_cb,
-            cls.chooser_cb)
+        chooser.connect("file-activated", 
+                        cls.on_file_click_cb, 
+                        window, response_cb)
+
+        cls.add_button(window, gtk.STOCK_CANCEL, 
+                       stock.CANCEL, response_cb,
+                       cls.chooser_cb)
+
+        cls.add_button(window, gtk.STOCK_OPEN, 
+                       stock.OPEN, response_cb,
+                       cls.chooser_cb)
 
         window.show_all()
 
@@ -710,6 +716,16 @@ class Dialog(object):
         box.set_property('row-spacing', 4)
         box.set_property('column-spacing', 4)
 
+        def expander_toggled(expander,param):
+            if not expander.get_expanded():
+                expander.remove(box)
+                window.resize(150,100)
+            else:            
+                expander.add(box)
+                window.show_all()
+
+        advanced.connect('notify::expanded',expander_toggled)
+
         try:
             s_name = getattr(gui.theme.image_theme, "service_" + service)
             session_pixbuf = utils.safe_gtk_pixbuf_load(s_name)
@@ -838,10 +854,8 @@ class Dialog(object):
         session_box.pack_start(session_image)
         session_box.pack_start(session_label)
 
-        advanced.add(box)
         content.pack_start(session_box, False)
         content.pack_start(advanced, False)
-
         cls.add_button(window, gtk.STOCK_CANCEL, stock.CANCEL, response_cb,
                 button_cb)
         cls.add_button(window, gtk.STOCK_OK, stock.ACCEPT, response_cb,
@@ -905,7 +919,9 @@ class Dialog(object):
             windows.hide()
 
         savebutt.connect('clicked', save_profile)
-        avatarEventBox.connect("button-press-event", handler.on_set_picture_selected)
+        if handler.session.session_has_service(e3.Session.SERVICE_PROFILE_PICTURE):
+            avatarEventBox.connect("button-press-event", 
+                                   handler.on_set_picture_selected)
 
         vbox0 = gtk.VBox()
 
@@ -927,8 +943,10 @@ class Dialog(object):
         class TableText(gtk.Alignment):
             '''class that implements selectable labels aligned to the left'''
             def __init__(self, text):
-                gtk.Alignment.__init__(self, xalign=0.0, yalign=0.0, xscale=0.0,
-                                       yscale=0.0)
+                gtk.Alignment.__init__(self, 
+                                       xalign=0.0, yalign=0.0, 
+                                       xscale=0.0, yscale=0.0)
+
                 self.label = gtk.Label(text)
                 self.label.set_selectable(True)
                 self.add(self.label)
@@ -1784,7 +1802,6 @@ class ProgressWindow(gtk.Window):
         gtk.Window.__init__(self)
         self.set_title(title)
         self.set_role("dialog")
-        self.set_modal(True)
         self.buttoncancel = gtk.Button()
         self.buttoncancel.set_label(_("Cancel"))
         self.buttoncancel.connect('clicked', callback)
@@ -1818,13 +1835,15 @@ class WebWindow(gtk.Window):
         gtk.Window.__init__(self)
         self.set_title(title)
         self._callback = callback
+        scroll = gtk.ScrolledWindow()
         bro = webkit.WebView()
+        bro.set_size_request(350, 350)
         bro.connect('load-committed', self._load_committed_cb)
         bro.open(url)
-        self.add(bro)
+        scroll.add(bro)
+        self.add(scroll)
 
     def _load_committed_cb(self, web_view, frame):
         uri = frame.get_uri()
         if self._callback != None:
             self._callback(uri)
-        
