@@ -85,12 +85,25 @@ class ExtensionList(gtk.VBox):
         self.list_store.clear()
         self.extension_list = []
 
-    def append(self, is_active, label, name, sensitive=True, visible=True, path='', type_=''):
+    def prettify_name(self, name, description):
+        '''return a prettier name for the plugin with its description in a new
+        line, using Pango markup.
+        '''
+        name = name.replace('_', ' ')
+        if description:
+            pretty_name = '<span><b>%s</b>\n<small>%s</small></span>' % \
+                          (name.capitalize(), description)
+        else:
+            pretty_name = '<span><b>%s</b></span>' % name.capitalize()
+        return pretty_name
+
+    def append(self, is_active, label, name, sensitive=True, visible=True, path='', type_='', description=''):
         '''append an item'''
+        pretty_name = self.prettify_name(label, description)
         if not sensitive:
-            label = '<span foreground="#696969">%s</span>' % label
+            pretty_name = '<span foreground="#696969">%s</span>' % pretty_name
         if name not in self.extension_list:
-            self.list_store.append((is_active, label, name, sensitive, visible, path, type_))
+            self.list_store.append((is_active, pretty_name, name, sensitive, visible, path, type_))
             self.extension_list.append(name)
 
 class ExtensionListTab(gtk.VBox):
@@ -139,6 +152,10 @@ class ExtensionListTab(gtk.VBox):
         self.lists.append_page(extension_list, label)
         return extension_list
 
+    def strip_name(self, name, *args):
+        '''called to strip names when needed'''
+        return name
+
     def on_toggled(self, *args):
         '''called when a checkbox is toggled'''
         pass
@@ -147,14 +164,6 @@ class ExtensionListTab(gtk.VBox):
         '''called when a row is selected'''
         pass
 
-    def prettify_name(self, name, type_='', description=''):
-        '''return a prettier name for the plugin with its description in a new
-        line, using Pango markup.
-        '''
-        name = name.replace('_', ' ')
-        pretty_name = '<span><b>%s</b>\n<small>%s</small></span>'
-        return pretty_name % (name.capitalize(), description)
-
     def get_attr(self, name):
         """return the value of an attribute, if it has dots, then
         get the values until the last
@@ -190,27 +199,109 @@ class ExtensionListTab(gtk.VBox):
         split_version.reverse()
         value = 0
         for i, val in enumerate(split_version):
-            value += (int(val) << ((3-i) * 8))
+            value += (int(val) << (i * 8))
 
-class ExtensionDownloadList(ExtensionListTab):
-    def __init__(self, session, list_type,
-                 collection_class, init_path,
-                 radio=False, use_tabs=False):
+        return value
+
+
+class DownloadListBase(ExtensionListTab):
+    def __init__(self, session, radio=False, use_tabs=False):
         '''constructor'''
         ExtensionListTab.__init__(self, session, radio, use_tabs)
-        self.first = True
-        self.done = True
+        self.updated_amount = 0
 
-        self.thc_com = {}
-        self.list_type = list_type
+        self.config_dir = e3.common.ConfigDir('emesene2')
 
-        supported = _('Supported')
-        community = _('Community')
+        self.list_types = ['plugins', 'themes']
 
-        self.thc_cur_name = supported
+        self.collections = \
+        {
+            'plugins':
+            {
+                'supported': extension.get_and_instantiate(
+                                'supported plugins collection',
+                                self.config_dir.join('plugins')),
+                'community': extension.get_and_instantiate(
+                                'community plugins collection',
+                                self.config_dir.join('plugins'))
+            },
+            'themes':
+            {
+                'supported': extension.get_and_instantiate(
+                                'supported themes collection',
+                                self.config_dir.join('themes')),
+                'community': extension.get_and_instantiate(
+                                'community themes collection',
+                                self.config_dir.join('themes'))
+            }
+        }
 
-        self.thc_com[supported] = collection_class('emesene-supported-' + self.list_type, init_path)
-        self.thc_com[community] = collection_class('emesene-community-' + self.list_type, init_path)
+    def on_update(self, widget=None, refresh=False):
+        '''called when the liststore need to be changed'''
+        dialog = extension.get_default('dialog')
+        self.progress = dialog.progress_window(
+                        _('Refresh extensions'), self._end_progress_cb)
+        self.progress.set_action(_("Refreshing extensions"))
+        self.progress.show_all()
+        gobject.timeout_add(100, self.update_progress)
+        utils.GtkRunner(self.show_update_callback, self.update, refresh)
+
+    def update(self, refresh):
+        '''update the collection data'''
+        self.updated_amount = 0
+        for list_type in self.list_types:
+            for current_collection in self.collections[list_type].itervalues():
+                current_collection.fetch(refresh)
+                if self.progress is None:
+                    return
+
+                current_collection.fetch_all_metadata(refresh)
+                if self.progress is None:
+                    return
+
+                self.updated_amount += 1
+
+    def update_progress(self):
+        if not self.progress:
+            return False
+
+        progress = self.updated_amount / (len(self.list_types) * 2.0)
+        for collection in self.collections.itervalues():
+            for current_collection in collection.itervalues():
+                progress += current_collection.progress / (len(self.list_types) * 2.0)
+
+        self.progress.update(100.0 * progress)
+
+        return True
+
+    def show_update_callback(self, result=None):
+        '''method used as callback, because both GtkRunner and buttons
+        need the first argument on the on_update method'''
+        if result is not None and not result[0]:
+            log.error(str(result[1]))
+        if self.progress is None:
+            return
+
+        self.progress.destroy()
+        self.progress = None
+        self.show_update()
+
+    def _end_progress_cb(self, *args):
+        '''stops download of plugins'''
+        for collection in self.collections.itervalues():
+            for current_collection in collection.itervalues():
+                current_collection.stop()
+        self.show_update_callback()
+
+class DownloadList(DownloadListBase):
+    def __init__(self, session, list_type, init_path,
+                 radio=False, use_tabs=False):
+        '''constructor'''
+        DownloadListBase.__init__(self, session, radio, use_tabs)
+
+        self.list_types = [list_type]
+
+        self.current_collection = self.collections[list_type]['supported']
 
         self.download_list = {}
         self.removable_list = {}
@@ -231,10 +322,14 @@ class ExtensionDownloadList(ExtensionListTab):
         self.no_button = gtk.HBox()
         self.no_button2 = gtk.HBox()
 
-        source_combo = gtk.combo_box_new_text()
+        combo_store = gtk.ListStore(str, str)
+        combo_store.append((_('Supported'), 'supported'))
+        combo_store.append((_('Community'), 'community'))
 
-        source_combo.append_text(supported)
-        source_combo.append_text(community)
+        source_combo = gtk.ComboBox(combo_store)
+        cell = gtk.CellRendererText()
+        source_combo.pack_start(cell, True)
+        source_combo.add_attribute(cell, 'text', 0)
         source_combo.set_active(0)
         source_combo.connect('changed', self.on_change_source)
 
@@ -274,28 +369,14 @@ class ExtensionDownloadList(ExtensionListTab):
             name = model.get_value(iter, 2)
             return name
         else:
-            return None # Q: should something be done here?
+            return None
 
     def on_change_source(self, combobox):
         '''called when the source is changed'''
-        self.thc_cur_name = combobox.get_active_text()
-        self.on_update(clear=True)
-
-    def on_update(self, widget=None, download=False, clear=False):
-        '''called when the liststore need to be changed'''
-        if self.first or download:
-            dialog = extension.get_default('dialog')
-            self.progress = dialog.progress_window(
-                            _('Refresh extensions'), self._end_progress_cb)
-            self.progress.set_action(_("Refreshing extensions"))
-            self.progress.show_all()
-            self.done = False
-            gobject.timeout_add(100, self.update_progress)
-            utils.GtkRunner(self.show_update_callback, self.update)
-
-            self.first = False
-        elif clear:
-            self.show_update()
+        index = combobox.get_active()
+        collection_type = combobox.get_model()[index][1]
+        self.current_collection = self.collections[self.list_types[0]][collection_type]
+        self.show_update()
 
     def start_download(self, widget=None):
         '''start the download of an extension'''
@@ -304,46 +385,28 @@ class ExtensionDownloadList(ExtensionListTab):
                         _('Downloading extensions'), self._end_progress_cb)
         self.progress.set_action(_("Downloading extensions"))
         self.progress.show_all()
-        self.done = False
         gobject.timeout_add(100, self.update_progress)
         utils.GtkRunner(self.show_update_callback, self.download)
 
     def download(self):
         '''download an extension'''
-        thc_cur = self.thc_com[self.thc_cur_name]
-        thc_cur.download(self.download_item)
+        self.updated_amount = 0
+        self.current_collection.download(self.download_item)
 
     def remove(self, widget):
         '''remove an extension'''
-        thc_cur = self.thc_com[self.thc_cur_name]
         path = self.removable_list[self.remove_item[0]][self.remove_item[1]]
-        thc_cur.remove(path)
+        self.current_collection.remove(path)
         self.removable_list[self.remove_item[0]].pop(self.remove_item[1])
-        self.on_update(clear=True)
+        self.show_update()
 
-    def update(self):
-        '''update the collections'''
-        for item in self.thc_com.itervalues():
-            item.fetch()
-
-    def update_progress(self):
-        thc_cur = self.thc_com[self.thc_cur_name]
-        self.progress.update(100.0 * thc_cur.progress)
-        if self.done:
-            return False
-        return True
-
-    def show_update_callback(self, result=None):
-        '''method used as callback, because both GtkRunner and buttons
-        need the first argument on the on_update method'''
-        if result is not None and not result[0]:
-            log.error(str(result[1]))
-        self.done = True
-        self.progress.destroy()
-        self.on_update(clear=True)
+    def fetch_metadata(self, type_, name):
+        ''' fetch metadata '''
+        meta = self.current_collection.fetch_metadata(type_, name)
+        return meta
 
     def check_version(self, type_, name):
-        meta = self.thc_com[self.thc_cur_name].fetch_metadata(type_, name)
+        meta = self.fetch_metadata(type_, name)
         if not meta or not meta.get('required emesene version'):
             return True
 
@@ -357,14 +420,12 @@ class ExtensionDownloadList(ExtensionListTab):
         '''show an update list of the set collection'''
         self.download_list = {}
 
-        thc_cur = self.thc_com[self.thc_cur_name]
-
         for box in self.boxes:
             if box.extension_type not in self.download_list:
                 self.download_list[box.extension_type] = []
 
-            element = thc_cur.extensions_descs.get(box.extension_type, {})
-            box.append(False, '<b>'+_('Available for download')+'</b>',
+            element = self.current_collection.extensions_descs.get(box.extension_type, {})
+            box.append(False, _('Available for download'),
                        'installable', visible=False)
 
             for label in element:
@@ -373,22 +434,15 @@ class ExtensionDownloadList(ExtensionListTab):
                 if label not in box.extension_list:
                     self.download_list[box.extension_type].append(label)
 
-                box.append(False,
-                           self.prettify_name(label, box.extension_type),
-                           label,
-                           False)
+                box.append(False, self.strip_name(label, box.extension_type),
+                           label, False, description=self.fetch_metadata(
+                                box.extension_type, label).get('description'))
 
-    def _end_progress_cb(self, *args):
-        '''stops download of plugins'''
-        for item in self.thc_com.itervalues():
-            item.stop()
-            self.done = True
-
-class ThemeList(ExtensionDownloadList):
+class ThemeList(DownloadList):
     def __init__(self, session):
         self.config_dir = e3.common.ConfigDir('emesene2')
-        ExtensionDownloadList.__init__(
-            self, session, 'themes', e3.common.Collections.ThemesCollection,
+        DownloadList.__init__(
+            self, session, 'themes',
             self.config_dir.join('themes'), True, True)
 
         self.themes = {}
@@ -409,18 +463,15 @@ class ThemeList(ExtensionDownloadList):
     def set_theme(self, property_name, value):
         self.set_attr(property_name, value)
 
-    def on_update(self, widget=None, download=False, clear=False):
+    def show_update(self):
         '''called when the liststore need to be changed'''
-        if not (self.first or download or clear):
-            return
-
         self.removable_list = {}
 
         for box in self.boxes:
             if box.extension_type not in self.removable_list:
                 self.removable_list[box.extension_type] = {}
             box.clear_all()
-            box.append(False, '<b>'+_('Installed')+'</b>',
+            box.append(False, _('Installed'),
                        'installed', visible=False)
 
             current = self.get_attr(self.theme_configs[box.extension_type])
@@ -431,11 +482,10 @@ class ThemeList(ExtensionDownloadList):
                 if path.startswith(self.config_dir.base_dir) and not is_current:
                     self.removable_list[box.extension_type][name] = path
                 box.append(is_current, label, name, path=path)
-        ExtensionDownloadList.on_update(self, widget, download, clear)
+        DownloadList.show_update(self)
 
-    def prettify_name(self, name, type_):
-        '''return a prettier name using Pango markup.
-        '''
+    def strip_name(self, name, type_):
+        '''return a stripped version of theme name.'''
         name = name.replace('_', ' ')
         name = self.themes[type_].pattern.sub('', name)
         return '%s' % name
@@ -451,32 +501,16 @@ class ThemeList(ExtensionDownloadList):
         box = self.append_tab(name, theme_type, True)
         return box
 
-class UpdateList(ExtensionListTab):
+class UpdateList(DownloadListBase):
     def __init__(self, session):
-        ExtensionListTab.__init__(self, session)
+        DownloadListBase.__init__(self, session)
         self.update_list = {'plugins': {}, 'themes': {}}
 
-        self.first = True
-        self.done = True
-
-        self.config_dir = e3.common.ConfigDir('emesene2')
+        self.update_amount = 0
 
         self.themes = {}
         self.theme_names = {}
         self.theme_configs = {}
-        self.collections = \
-        {
-            'plugins':
-            {
-                'supported': e3.common.Collections.PluginsCollection('emesene-supported-plugins', self.config_dir.join('plugins')),
-                'community': e3.common.Collections.PluginsCollection('emesene-community-plugins', self.config_dir.join('plugins'))
-            },
-            'themes':
-            {
-                'supported': e3.common.Collections.ThemesCollection('emesene-supported-themes', self.config_dir.join('themes')),
-                'community': e3.common.Collections.ThemesCollection('emesene-community-themes', self.config_dir.join('themes'))
-            }
-        }
 
         self.download_button = gtk.Button(_('Update'))
         self.download_button.set_image(gtk.image_new_from_stock(
@@ -498,24 +532,15 @@ class UpdateList(ExtensionListTab):
         else:
             del item[model[path][2]]
 
-    def show_update_callback(self, result=None):
-        '''method used as callback, because both GtkRunner and buttons
-        need the first argument on the on_update method'''
-        if result is not None and not result[0]:
-            log.error(str(result[1]))
-        self.done = True
-        self.progress.destroy()
-        self.on_update(clear=True)
-
-    def download(self, name, cur_thc):
+    def download(self, name, current_extension):
         '''download an extension'''
-        cur_thc.download(name)
+        current_extension.download(name)
 
-    def remove(self, path, cur_thc):
+    def remove(self, path, current_extension):
         '''remove an extension'''
-        cur_thc.remove(path)
+        current_extension.remove(path)
 
-    def get_thc(self, collection, type_, name):
+    def get_collection(self, collection, type_, name):
         if self.collections[collection]['supported'].has_item(type_, name):
             return self.collections[collection]['supported']
         elif self.collections[collection]['community'].has_item(type_, name):
@@ -528,19 +553,39 @@ class UpdateList(ExtensionListTab):
                         _('Updating extensions'), self._end_progress_cb)
         self.progress.set_action(_("Updating extensions"))
         self.progress.show_all()
-        self.done = False
-        gobject.timeout_add(100, self.update_progress)
+        gobject.timeout_add(100, self.update_download_progress)
         utils.GtkRunner(self.show_update_callback, self.download_updates)
 
     def download_updates(self):
+        self.updated_amount = 0
         for collection_name, items in self.update_list.iteritems():
             for ext_type, ext_list in items.iteritems():
                 for ext, path in ext_list.iteritems():
-                    cur_thc = self.get_thc(collection_name, ext_type, ext)
-                    self.remove(path, cur_thc)
-                    self.download(ext, cur_thc)
+                    if self.progress is None:
+                        return
+
+                    current_extension = self.get_collection(collection_name, ext_type, ext)
+                    self.remove(path, current_extension)
+                    self.download(ext, current_extension)
+                    self.updated_amount += 1
                 ext_list = {}
-        self.on_update(clear=True)
+        self.show_update()
+
+    def update_download_progress(self):
+        if not self.progress:
+            return False
+
+        if not self.update_amount:
+            progress = 1.0
+        else:
+            progress = self.updated_amount / float(self.update_amount)
+            for collection in self.collections.itervalues():
+                for current_collection in collection.itervalues():
+                    progress += current_collection.progress / float(self.update_amount)
+
+        self.progress.update(100.0 * progress)
+
+        return True
 
     def fetch_metadata(self, collection, type_, name):
         meta = self.collections[collection]['supported'].fetch_metadata(type_, name)
@@ -574,6 +619,7 @@ class UpdateList(ExtensionListTab):
     def show_update(self):
         '''called when the liststore need to be changed'''
         self.clear_all()
+        self.update_amount = 0
 
         for theme_type in self.themes.iterkeys():
             first = True
@@ -584,11 +630,12 @@ class UpdateList(ExtensionListTab):
                 if not self.check_updates('themes', theme_type, path):
                     continue
                 if first:
-                    self.append(False, '<b>'+self.theme_names[theme_type]+'</b>', theme_type, visible=False)
+                    self.append(False, self.theme_names[theme_type], theme_type, visible=False)
                     first = False
                 name = os.path.basename(path)
                 label = self.themes[theme_type].get_name_from_path(path)
                 self.update_list['themes'][theme_type][name] = path
+                self.update_amount += 1
                 self.append(True, label, name, path=path, type_=theme_type)
 
         pluginmanager = get_pluginmanager()
@@ -602,56 +649,14 @@ class UpdateList(ExtensionListTab):
             if not self.check_updates('plugins', 'plugin', path, plugin):
                 continue
             if first:
-                self.append(False, '<b>' + _('Plugins') + '</b>', 'installed', True, False)
+                self.append(False, _('Plugins'), 'installed', True, False)
                 first = False
             self.update_list['plugins']['plugin'][name] = path
-            self.append(True, self.prettify_name(name,
-                        description=pluginmanager.plugin_description(name)),
-                        name, path=path, type_='plugin')
-
-
-    def on_update(self, widget=None, download=False, clear=False):
-        '''called when the liststore need to be changed'''
-        if self.first or download:
-            dialog = extension.get_default('dialog')
-            self.progress = dialog.progress_window(
-                            _('Refresh extensions'), self._end_progress_cb)
-            self.progress.set_action(_("Refreshing extensions"))
-            self.progress.show_all()
-            self.done = False
-            gobject.timeout_add(100, self.update_progress)
-            utils.GtkRunner(self.show_update_callback, self.update)
-
-            self.first = False
-        elif clear:
-            self.show_update()
-
-    def update(self):
-        '''update the collections'''
-        for collection in self.collections.itervalues():
-            for thc_cur in collection.itervalues():
-                thc_cur.fetch()
-
-    def update_progress(self):
-        progress = 0.0
-        for collection in self.collections.itervalues():
-            for thc_cur in collection.itervalues():
-                progress += thc_cur.progress / 4.0
-
-        self.progress.update(100.0 * progress)
-
-        if self.done:
-            return False
-        return True
+            self.update_amount += 1
+            self.append(True, name, name, path=path, type_='plugin',
+                        description=pluginmanager.plugin_description(name))
 
     def append_theme(self, name, theme_type, theme, theme_config):
         self.themes[theme_type] = theme
         self.theme_configs[theme_type] = theme_config
         self.theme_names[theme_type] = name
-
-    def _end_progress_cb(self, *args):
-        '''stops download of plugins'''
-        for collection in self.collections.itervalues():
-            for thc_cur in collection.itervalues():
-                thc_cur.stop()
-        self.done = True
