@@ -237,11 +237,11 @@ class FileTransferTooltip(gtk.Window):
 
         self.pointer_is_over_widget = False
 
-        self.__fileprev=None
+        self.__fileprev = None
 
     def add_label(self, l_string, left, right, top, bottom, label = None):
         ''' adds a label to the widget '''
-        if label == None:
+        if label is None:
             label = gtk.Label(l_string)
 
         label.set_alignment(0, 0)
@@ -262,7 +262,7 @@ class FileTransferTooltip(gtk.Window):
             return
 
         if self.transfer.preview is not None:
-            if(self.__fileprev==None):
+            if self.__fileprev is None:
                 self.__fileprev=tempfile.mkstemp(prefix=hashlib.md5(self.transfer.preview).hexdigest(), 
                                                  suffix=hashlib.md5(self.transfer.preview).hexdigest())[1]
 
