@@ -80,7 +80,7 @@ class Preferences(gtk.Window):
         treeViewColumn = gtk.TreeViewColumn(_('Categories'))
 
         treeViewColumn.pack_start(cellPix, expand=False)
-        treeViewColumn.add_attribute(cellPix, 'pixbuf',0)
+        treeViewColumn.add_attribute(cellPix, 'pixbuf', 0)
         treeViewColumn.pack_start(cellText, expand=True)
         treeViewColumn.set_attributes(cellText, text=1)
 
@@ -99,9 +99,9 @@ class Preferences(gtk.Window):
 
         vbox.set_spacing(4)
         hbox = gtk.HBox(homogeneous=False, spacing=5)
-        hbox.pack_start(treeView, True,True) # False, True
+        hbox.pack_start(treeView, True, True) # False, True
         hbox.pack_start(self.notebook, True, True)
-        vbox.pack_start(hbox, True,True) # hbox, True, True
+        vbox.pack_start(hbox, True, True) # hbox, True, True
 
         config_dir = e3.common.ConfigDir('emesene2')
 
@@ -191,8 +191,10 @@ class Preferences(gtk.Window):
                              gtk.ICON_SIZE_LARGE_TOOLBAR), i['text']])
 
         msn_in_list = False
+        fb_in_list = False
         for pair in LIST:
             msn_in_list = msn_in_list or pair['text'] == _('Live Messenger')
+            fb_in_list = fb_in_list or pair['text'] == _('Facebook')
 
         if 'msn' in self.session.SERVICES:
         # only when session is papylib.
@@ -200,8 +202,8 @@ class Preferences(gtk.Window):
                 LIST.append({'stock_id' : gtk.STOCK_NETWORK,
                                  'text' : _('Live Messenger')})
                 self.listStore.append([self.render_icon(gtk.STOCK_NETWORK,
-                                       gtk.ICON_SIZE_LARGE_TOOLBAR),
-                                       _('Live Messenger')])
+                                      gtk.ICON_SIZE_LARGE_TOOLBAR),
+                                      _('Live Messenger')])
             self.msn_papylib = MSNPapylib(self.session)
             self.msn_papylib_page = self.msn_papylib
             self.page_dict.append(self.msn_papylib_page)
@@ -210,9 +212,24 @@ class Preferences(gtk.Window):
                          'text' : _('Live Messenger')})
             self.__refresh_list()
 
+        if 'facebook' in self.session.SERVICES:
+        # only when session is papylib.
+            if not fb_in_list:
+                LIST.append({'stock_id' : gtk.STOCK_NETWORK,
+                                 'text' : _('Facebook')})
+                self.listStore.append([self.render_icon(gtk.STOCK_NETWORK,
+                                      gtk.ICON_SIZE_LARGE_TOOLBAR),
+                                      _('Facebook')])
+            self.facebook = Facebook(self.session)
+            self.facebook_page = self.facebook
+            self.page_dict.append(self.facebook_page)
+        elif fb_in_list:
+            LIST.remove({'stock_id' : gtk.STOCK_NETWORK,
+                         'text' : _('Facebook')})
+            self.__refresh_list()
 
         for i in range(len(self.page_dict)):
-           self.notebook.append_page(self.page_dict[i])
+            self.notebook.append_page(self.page_dict[i])
 
     def __refresh_list(self):
 
@@ -222,9 +239,9 @@ class Preferences(gtk.Window):
             # we should use always the same icon size,
             # we can remove that field in LIST
             self.listStore.append([self.render_icon(i['stock_id'],
-                             gtk.ICON_SIZE_LARGE_TOOLBAR), i['text']])
+                                  gtk.ICON_SIZE_LARGE_TOOLBAR), i['text']])
 
-    def _on_row_activated(self,treeview):
+    def _on_row_activated(self, treeview):
         # Get information about the row that has been selected
         cursor, obj = treeview.get_cursor()
         self.showPage(cursor[0])
@@ -248,14 +265,16 @@ class BaseTable(gtk.Table):
 
         self.current_row = 0
 
-    def add_text(self, text, column, row, align_left=False, line_wrap=True):
+    def add_text(self, text, column, row, 
+                 align_left=False, line_wrap=True):
         """add a label with thext to row and column, align the text left if
         align_left is True
         """
         label = gtk.Label(text)
         self.add_label(label, column, row, align_left)
 
-    def add_label(self, label, column, row, align_left=False, line_wrap=True):
+    def add_label(self, label, column, row,
+                  align_left=False, line_wrap=True):
         """add a label with thext to row and column, align the text left if
         align_left is True
         """
@@ -265,7 +284,9 @@ class BaseTable(gtk.Table):
         label.set_line_wrap(line_wrap)
         self.attach(label, column, column + 1, row, row + 1, yoptions=0)
 
-    def add_button(self, text, column, row, on_click, xoptions=gtk.EXPAND|gtk.FILL, yoptions=gtk.EXPAND|gtk.FILL):
+    def add_button(self, text, column, row, 
+                   on_click, xoptions=gtk.EXPAND|gtk.FILL, 
+                   yoptions=gtk.EXPAND|gtk.FILL):
         """add a button with text to the row and column, connect the clicked
         event to on_click"""
         button = gtk.Button(text)
@@ -277,7 +298,7 @@ class BaseTable(gtk.Table):
         """append a row to the table
         """
         increment_current_row = False
-        if row == None:
+        if row is None:
             row = self.current_row
             increment_current_row = True
 
@@ -353,7 +374,8 @@ class BaseTable(gtk.Table):
         self.append_row(widget, row)
         return widget
 
-    def append_range(self, text, property_name, min_val, max_val,is_int=True):
+    def append_range(self, text, property_name, 
+                     min_val, max_val,is_int=True):
         """append a row with a scale to select an integer value between
         min and max
         """
@@ -376,8 +398,8 @@ class BaseTable(gtk.Table):
         hbox.pack_start(label, True, True)
         hbox.pack_start(scale, False)
 
-        scale.connect('button_release_event', self.on_range_changed, property_name,
-                is_int)
+        scale.connect('button_release_event', self.on_range_changed,
+                      property_name, is_int)
 
         self.append_row(hbox, None)
 
@@ -397,17 +419,24 @@ class BaseTable(gtk.Table):
 
         combo.set_active(default_count)
 
-    def create_combo (self, getter, property_name, values=None, changed_cb = None):
+    def create_combo (self, getter, property_name,
+                      values=None, changed_cb = None):
+
         combo = gtk.combo_box_new_text()
         self.fill_combo(combo, getter, property_name, values)
         if changed_cb:
-            combo.connect('changed', changed_cb, property_name, values)
+            combo.connect('changed', changed_cb, 
+                          property_name, values)
         else:
-            combo.connect('changed', self.on_combo_changed, property_name, values)
+            combo.connect('changed', self.on_combo_changed,
+                          property_name, values)
         return combo
 
-    def create_combo_with_label(self, text, getter, property_name,values=None, changed_cb = None):
-        """creates and return a new ComboBox with a label and append values to the combo
+    def create_combo_with_label(self, text, 
+                                getter, property_name, 
+                                values=None, changed_cb = None):
+        """creates and return a new ComboBox with a label and append 
+           values to the combo
         """
         hbox = gtk.HBox()
         hbox.set_homogeneous(True)
@@ -420,10 +449,10 @@ class BaseTable(gtk.Table):
 
         return hbox
 
-    def append_combo(self, text, getter, property_name,values=None):
+    def append_combo(self, text, getter, property_name, values=None):
         """append a label and a combo and adds values to it
         """
-        hbox = self.create_combo_with_label(text, getter, property_name,values)
+        hbox = self.create_combo_with_label(text, getter, property_name, values)
         self.append_row(hbox, None)
 
     def append_markup(self, text):
@@ -508,8 +537,8 @@ class BaseTable(gtk.Table):
         self.session.signals.login_succeed.emit()
         self.session.signals.contact_list_ready.emit()
 
-    def on_synch_emesene1(self, button):
-        """called when the Synch test button is clicked"""
+    def on_import_emesene1(self, button):
+        """called when the Import button is clicked"""
         syn = extension.get_default('synch tool')
         current_service = self.session.config.service
         syn = syn(self.session, current_service)
@@ -546,15 +575,25 @@ class MainWindow(BaseTable):
 
             def do_hideshow(widget):
                 if widget.get_active():
-                    subprocess.call('defaults write /Applications/emesene.app/Contents/Info LSUIElement -bool false', shell=True)
+                    subprocess.call('defaults write '
+                                    '/Applications/emesene.app/Contents/Info'
+                                    ' LSUIElement -bool false', shell=True)
                 else:
-                    subprocess.call('defaults write /Applications/emesene.app/Contents/Info LSUIElement -bool true', shell=True)
+                    subprocess.call('defaults write '
+                                    '/Applications/emesene.app/Contents/Info'
+                                    ' LSUIElement -bool true', shell=True)
 
             self.append_markup('<b>'+_('OS X Integration:')+'</b>')
             self.session.config.get_or_set('b_show_dock_icon', False)    
-            button = self.append_check(_('Show dock icon (requires restart of emesene)'),
-                         'session.config.b_show_dock_icon')
+            
+            button = self.append_check(_('Show dock icon '
+                                       '(requires restart of emesene)'),
+                                       'session.config.b_show_dock_icon')
             button.connect("toggled", do_hideshow)
+            self.session.config.get_or_set('b_hide_menu', True)    
+            button = self.append_check(_('Hide menu'),
+                                       'session.config.b_hide_menu')
+
 
         self.show_all()
 
@@ -585,7 +624,8 @@ class ConversationWindow(BaseTable):
             index += 1
 
         cb_check_spelling = self.create_check(
-            _('Enable spell check if available (requires %s)') % 'python-gtkspell',
+            _('Enable spell check if available (requires %s)') 
+            % 'python-gtkspell',
             'session.config.b_enable_spell_check')
 
         h_lang_box = gtk.HBox()
@@ -594,15 +634,18 @@ class ConversationWindow(BaseTable):
 
         # override text color option
 
-        cb_override_text_color = self.create_check(_('Override incoming text color'),
-            'session.config.b_override_text_color')
+        cb_override_text_color = self.create_check(
+                                        _('Override incoming text color'),
+                                        'session.config.b_override_text_color')
+
         self.session.config.subscribe(self._on_cb_override_text_color_toggled,
             'b_override_text_color')
 
         def on_color_selected(cb):
             col = cb.get_color()
             col_e3 = e3.base.Color(col.red, col.green, col.blue)
-            self.set_attr('session.config.override_text_color', '#'+col_e3.to_hex())
+            self.set_attr('session.config.override_text_color', 
+                          '#'+col_e3.to_hex())
 
         self.b_text_color = gtk.ColorButton(color=gtk.gdk.color_parse(
                             self.get_attr('session.config.override_text_color')))
@@ -621,22 +664,24 @@ class ConversationWindow(BaseTable):
         self.session.config.get_or_set('b_avatar_on_left', False)
         self.session.config.get_or_set('b_toolbar_small', False)
         self.session.config.get_or_set('b_conversation_tabs', True)
-        self.session.config.get_or_set('b_conv_tab_popup', False)
         self.session.config.get_or_set('b_escape_hotkey', True)
+        self.session.config.get_or_set('b_close_button_on_tabs', True)
         self.append_check(_('Tabbed Conversations'),
                 'session.config.b_conversation_tabs')
         self.append_row(self.tab_pos_cb)
         self.session.config.get_or_set('b_show_avatar_in_taskbar', True)
-        self.append_check(_('Start minimized/iconified'), 'session.config.b_conv_minimized')
-        self.append_check(_('Show emoticons'), 'session.config.b_show_emoticons')
+        self.append_check(_('Start minimized/iconified'),
+                          'session.config.b_conv_minimized')
+        self.append_check(_('Show emoticons'),
+                          'session.config.b_show_emoticons')
         self.append_check(_('Show conversation header'),
             'session.config.b_show_header')
         self.append_check(_('Show conversation side panel'),
             'session.config.b_show_info')
         self.append_check(_('Show conversation toolbar'),
             'session.config.b_show_toolbar')
-        self.append_check(_('Show tabs popup menu'),
-            'session.config.b_conv_tab_popup')
+        self.append_check(_('Show close button on tabs'),
+            'session.config.b_close_button_on_tabs')
         self.append_check(_('Enable escape hotkey to close tabs'),
             'session.config.b_escape_hotkey')
         # small-toolbar sensitivity depends on conversation toolbar visibility
@@ -711,7 +756,7 @@ class ConversationWindow(BaseTable):
         self.session.config.spell_lang = combo.get_active_text()
 
     def get_tab_positions(self):
-        return [_("Top"),_("Bottom"),_("Left"),_("Right")]
+        return [_("Top"), _("Bottom"), _("Left"), _("Right")]
 
     def remove_subscriptions(self):
         self.session.config.unsubscribe(self._on_cb_show_toolbar_changed,
@@ -821,14 +866,24 @@ class Theme(BaseTable):
 
         self.tabs = ExtensionList.ThemeList(session)
 
-        self.tabs.append_theme_tab(_('Image theme'), 'images', gui.theme.image_themes,
-            'session.config.image_theme')
-        self.tabs.append_theme_tab(_('Sound theme'), 'sounds', gui.theme.sound_themes,
-            'session.config.sound_theme', self._on_sound_combo_changed)
-        self.tabs.append_theme_tab(_('Emote theme'), 'emotes', gui.theme.emote_themes,
-            'session.config.emote_theme')
-        adium_tab = self.tabs.append_theme_tab(_('Adium theme'), 'conversations', gui.theme.conv_themes,
-            'session.config.adium_theme', self._on_adium_theme_combo_changed)
+        self.tabs.append_theme_tab(_('Image theme'), 'images',
+                                   gui.theme.image_themes,
+                                   'session.config.image_theme')
+
+        self.tabs.append_theme_tab(_('Sound theme'), 'sounds',
+                                   gui.theme.sound_themes,
+                                   'session.config.sound_theme',
+                                   self._on_sound_combo_changed)
+
+        self.tabs.append_theme_tab(_('Emote theme'), 'emotes', 
+                                   gui.theme.emote_themes,
+                                   'session.config.emote_theme')
+
+        adium_tab = self.tabs.append_theme_tab(_('Adium theme'),
+                                           'conversations', 
+                                           gui.theme.conv_themes,
+                                           'session.config.adium_theme',
+                                           self._on_adium_theme_combo_changed)
         self.add(self.tabs)
 
         hbox = gtk.HBox(True)
@@ -850,7 +905,9 @@ class Theme(BaseTable):
         self.set_attr(property_name, value)
         gui.theme.sound_theme = value
 
-    def _on_adium_variant_combo_changed(self, combo, property_name, value):
+    def _on_adium_variant_combo_changed(self, combo, 
+                                        property_name, value):
+        
         variant_name = combo.get_active_text()
         #update adium variants combo
         self.set_attr(property_name, variant_name)
@@ -864,7 +921,8 @@ class Theme(BaseTable):
         #clear combo
         self.adium_variant_combo.get_model().clear()
         self.fill_combo(self.adium_variant_combo,
-            gui.theme.conv_theme.get_theme_variants, 'session.config.adium_theme_variant')
+            gui.theme.conv_theme.get_theme_variants,
+            'session.config.adium_theme_variant')
 
 class Update(BaseTable):
     """the panel to display/modify the config related to the theme
@@ -879,14 +937,21 @@ class Update(BaseTable):
 
         self.tabs = ExtensionList.UpdateList(session)
 
-        self.tabs.append_theme(_('Image theme'), 'images', gui.theme.image_themes,
-            'session.config.image_theme')
-        self.tabs.append_theme(_('Sound theme'), 'sounds', gui.theme.sound_themes,
-            'session.config.sound_theme')
-        self.tabs.append_theme(_('Emote theme'), 'emotes', gui.theme.emote_themes,
-            'session.config.emote_theme')
-        self.tabs.append_theme(_('Adium theme'), 'conversations', gui.theme.conv_themes,
-            'session.config.adium_theme')
+        self.tabs.append_theme(_('Image theme'), 'images',
+                               gui.theme.image_themes,
+                               'session.config.image_theme')
+                               
+        self.tabs.append_theme(_('Sound theme'), 'sounds',
+                               gui.theme.sound_themes,
+                               'session.config.sound_theme')
+
+        self.tabs.append_theme(_('Emote theme'), 'emotes',
+                               gui.theme.emote_themes,
+                               'session.config.emote_theme')
+
+        self.tabs.append_theme(_('Adium theme'), 'conversations',
+                               gui.theme.conv_themes,
+                               'session.config.adium_theme')
         self.add(self.tabs)
 
     def on_update(self):
@@ -943,8 +1008,8 @@ class Extension(BaseTable):
         self.add_button(_('Redraw main screen'), 0, 8,
                 self.on_redraw_main_screen, 0, 0)
 
-        self.add_button(_('Synch with emesene1'), 1, 8,
-                self.on_synch_emesene1, 0, 0)
+        self.add_button(_('Import from emesene1'), 1, 8,
+                self.on_import_emesene1, 0, 0)
 
     def _add_categories_and_extensions_combos(self):
         """add the widgets to display the extensions"""
@@ -1126,6 +1191,50 @@ class MSNPapylib(BaseTable):
         ''' called when live profile button is clicked '''
         gui.base.Desktop.open("http://profile.live.com/details/Edit/Pic")
 
+class Facebook(BaseTable):
+    """ This panel contains some facebook specific settings """
+
+    def __init__(self, session):
+        """constructor
+        """
+        BaseTable.__init__(self, 1, 1)
+        self.set_border_width(5)
+        self.session = session
+
+        self.append_markup('<b>'+_('Facebook Integration:')+'</b>')
+        self.append_check(_('Enable Facebook integration'),
+                          'session.config.b_fb_enable_integration')
+        self.append_check(_('Automatically check Facebook mail'),
+                          'session.config.b_fb_mail_check')
+        self.append_check(_('Automatically download Facebook status'),
+                          'session.config.b_fb_status_download')
+        self.append_check(_('Publish Facebook status'),
+                          'session.config.b_fb_status_write')
+        self.append_check(_('Automatically download profile photo'),
+                          'session.config.b_fb_picture_download')
+        # box with help message
+        eventBox = gtk.EventBox()
+        eventBox.modify_bg(gtk.STATE_NORMAL, gtk.gdk.Color('#EDDE5C'))
+
+        markup = '<span foreground="black"> %s </span>'
+        noticelabel = gtk.Label()
+        text = _("<b>WARNING: This will reset your facebook token."
+                 "\nemesene will ask you to login into facebook on"
+                 " next login</b>")
+
+        noticelabel.set_markup(markup % text)
+        eventBox.add(noticelabel)
+        self.append_row(eventBox, None)
+
+        self.add_button(_('Reset Facebook settings'), 0, 7,
+                self.reset_facebook_login, 0, 0)
+
+        self.show_all()
+
+    def reset_facebook_login(self, button):
+        '''Reset facebook integration settings'''
+        self.session.config.avatar_url = None
+        self.session.config.facebook_token = None
 
 class PrivacySettings(gtk.VBox):
     ''' A panel to manage contacts for MSN '''
@@ -1158,7 +1267,9 @@ class PrivacySettings(gtk.VBox):
         text = _('Yellow contacts don\'t have you in their contact list.')
         secondLabel.set_markup(markup % text)
         l_warning = gtk.Label()
-        text = _("<b>WARNING: The information provided below may be inaccurate.</b>")
+        text = _("<b>WARNING: The information provided below "
+                 "may be inaccurate.</b>")
+
         l_warning.set_markup(markup % text)
 
         labels_box.pack_start(firstLabel)
@@ -1277,7 +1388,7 @@ class PrivacySettings(gtk.VBox):
             selection = self.allow_view.get_selection()
             selection.unselect_all()
 
-        path = view.get_path_at_pos(int(event.x),int(event.y))
+        path = view.get_path_at_pos(int(event.x), int(event.y))
         if not path:
             selection = view.get_selection()
             selection.unselect_all()
