@@ -122,7 +122,9 @@ class CellRendererFunction(gtk.GenericCellRenderer):
 
     def get_layout(self, widget):
         '''Gets the Pango layout used in the cell in a TreeView widget.'''
-        layout = SmileyLayout(widget.create_pango_context())
+        layout = SmileyLayout(widget.create_pango_context(),
+                              color=widget.style.text[gtk.STATE_NORMAL],
+                              override_color=widget.style.text[gtk.STATE_SELECTED])
 
         if self.markup:
             try:
@@ -134,7 +136,6 @@ class CellRendererFunction(gtk.GenericCellRenderer):
                     decorated_markup = self.function(self.markup, False)
                 except Exception, error: #We really want to catch all exceptions
                     log.error("Even stripping plus markup doesn't help. Error: %s" % error)
-
                     decorated_markup = self.markup
 
             layout.set_text(decorated_markup)
@@ -209,7 +210,7 @@ class SmileyLayout(pango.Layout):
                  parsed_elements_list = None,
                  color = None,
                  override_color = None,
-                 scaling=1.0):
+                 scaling = 1.0):
         pango.Layout.__init__(self, context)
 
         self._width = -1
@@ -227,15 +228,8 @@ class SmileyLayout(pango.Layout):
         self._override_attrlist = None # with override color
         self.angle = 0
 
-        if color is None:
-            self._color = gtk.gdk.Color()
-        else:
-            self._color = color
-
-        if override_color is None:
-            self._override_color = gtk.gdk.Color()
-        else:
-            self._override_color = override_color
+        self._color = color
+        self._override_color = override_color
 
         self._smilies_scaled = {} # key: (index_pos), value(pixbuf)
         self._scaling = scaling # relative to ascent + desent, -1 for natural
@@ -291,18 +285,11 @@ class SmileyLayout(pango.Layout):
             self._update_attributes()
 
     def set_colors(self, color=None, override_color=None):
-        if color is None:
-            color = gtk.gdk.Color()
-
-        if override_color is None:
-            override_color = gtk.gdk.Color()
-
         self._color = color
         self._override_color = override_color
         self._update_attrlists()
 
     def _update_base(self, elements_list=None):
-
         if elements_list is None:
             elements_list = ['']
 
@@ -313,7 +300,7 @@ class SmileyLayout(pango.Layout):
         if isinstance(elements_list, basestring):
             elements_list = [elements_list]
 
-        for element in elements_list:
+        for element in elements_list:           
             if isinstance(element, basestring):
                 try:
                     attrl, ptxt, unused = pango.parse_markup(element, u'\x00')
@@ -326,7 +313,6 @@ class SmileyLayout(pango.Layout):
 
                 while True:
                     attrs = itter.get_attrs()
-
                     for attr in attrs:
                         attr.end_index += shift
                         attr.start_index += shift
@@ -391,16 +377,20 @@ class SmileyLayout(pango.Layout):
         self._update_attrlists()
 
     def _update_attrlists(self):
-        clr = self._color
-        oclr = self._override_color
-        norm_forground = pango.AttrForeground( clr.red,
-                clr.green, clr.blue, 0, len(self.get_text()))
-        override_forground = pango.AttrForeground( oclr.red,
-                oclr.green, oclr.blue, 0, len(self.get_text()))
         self._attrlist = pango.AttrList()
-        self._attrlist.insert(norm_forground)
+        if self._color:
+            clr = self._color
+            norm_forground = pango.AttrForeground(clr.red,
+                    clr.green, clr.blue, 0, len(self.get_text()))
+            self._attrlist.insert(norm_forground)
+
         self._override_attrlist = pango.AttrList()
-        self._override_attrlist.insert(override_forground)
+        if self._override_color:
+            oclr = self._override_color
+            override_forground = pango.AttrForeground(oclr.red,
+                    oclr.green, oclr.blue, 0, len(self.get_text()))
+            self._override_attrlist.insert(override_forground)
+
         itter = self._base_attrlist.get_iterator()
 
         while True:
