@@ -55,11 +55,16 @@ class TextBox(gtk.ScrolledWindow):
             self._textbox.connect('drag-data-received', self.on_drag_data_received)
 
         self._buffer = RichBuffer.RichBuffer()
+        self._buffer.connect('search_request', self._search_request_cb)
+
         self._textbox.set_buffer(self._buffer)
         self._textbox.connect_after('copy-clipboard', self._on_copy_clipboard)
         self.add(self._textbox)
         self.widgets = {}
 
+    def _search_request_cb(self, texbox, link):
+        self.emit("search_request", link)
+
     def clear(self):
         '''clear the content'''
         self._buffer.set_text('')
@@ -171,6 +176,10 @@ class TextBox(gtk.ScrolledWindow):
 
     text = property(fget=_get_text, fset=_set_text)
 
+gobject.type_register(TextBox)
+gobject.signal_new("search_request", TextBox, gobject.SIGNAL_RUN_FIRST,
+                   gobject.TYPE_NONE, (gobject.TYPE_PYOBJECT,))
+
 class InputView(gtk.TextView):
     __gsignals__ = {
         'message-send':(gobject.SIGNAL_RUN_LAST|gobject.SIGNAL_ACTION,
@@ -192,11 +201,13 @@ class InputText(TextBox):
     AUTHOR = 'Mariano Guerra'
     WEBSITE = 'www.emesene.org'
 
-    def __init__(self, session, on_send_message, on_cycle_history, on_drag_data_received):
+    def __init__(self, session, on_send_message, on_cycle_history,
+                on_drag_data_received, send_typing_notification):
         '''constructor'''
         TextBox.__init__(self, session.config, on_drag_data_received)
         self.on_send_message = on_send_message
         self.on_cycle_history = on_cycle_history
+        self.send_typing_notification = send_typing_notification
         self._tag = None
         self._textbox.connect('key-press-event', self._on_key_press_event)
         self._buffer.connect('changed', self.on_changed_event)
@@ -204,6 +215,7 @@ class InputText(TextBox):
 
         self.changed = False
         self.parse_timeout = None
+        self.typing_timeout = None
         self.invisible_tag = gtk.TextTag()
         self.invisible_tag.set_property('invisible', True)
         self._buffer.get_tag_table().add(self.invisible_tag)
@@ -253,9 +265,18 @@ class InputText(TextBox):
                     event.keyval == gtk.keysyms.Down):
 
             self.on_cycle_history(1)
+        else:
+            if self.typing_timeout is None:
+                self.send_typing_notification()
+                self.typing_timeout = gobject.timeout_add_seconds(3, self.reset_typing_timeout)
 
         if self.parse_timeout is None:
-            self.parse_timeout = gobject.timeout_add(500, self.parse_emotes)        
+            self.parse_timeout = gobject.timeout_add(500, self.parse_emotes)
+
+    def reset_typing_timeout(self):
+        '''emit typing notification'''
+        self.typing_timeout = None
+        return False
 
     def parse_emotes(self):
         """
@@ -362,13 +383,13 @@ class OutputText(TextBox):
     AUTHOR = 'Mariano Guerra'
     WEBSITE = 'www.emesene.org'
 
-    def __init__(self, config, add_emoticon_cb):
+    def __init__(self, config, handler):
         '''constructor'''
         TextBox.__init__(self, config)
         self.set_shadow_type(gtk.SHADOW_IN)
         self._textbox.set_editable(False)
         self._textbox.set_cursor_visible(False)
-        self.locked = False
+        self.locked = 0
         self.pending = []
 
     def clear(self, source="", target="", target_display="",
@@ -377,14 +398,16 @@ class OutputText(TextBox):
         TextBox.clear(self)
     
     def lock (self):
-        self.locked = True
+        self.locked += 1
 
     def unlock(self):
         #add messages and then unlock
-        for text in self.pending:
-            TextBox.append(self, text, self.config.b_allow_auto_scroll)
-        self.pending = []
-        self.locked = False
+        self.locked -=1
+        if self.locked <=0:
+            for text in self.pending:
+                TextBox.append(self, text, self.config.b_allow_auto_scroll)
+            self.pending = []
+            self.locked = 0
 
     def append(self, text, msg, scroll=True):
         '''append formatted text to the widget'''
