@@ -17,7 +17,7 @@
 #    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 import gtk
-
+import e3
 import gui
 
 import TextField
@@ -46,9 +46,10 @@ class UserPanel(gtk.VBox):
 
         self.avatarBox = gtk.EventBox()
         self.avatarBox.set_events(gtk.gdk.BUTTON_PRESS_MASK)
-        self.avatarBox.connect('button-press-event', self.on_avatar_click)
+        if session.session_has_service(e3.Session.SERVICE_PROFILE_PICTURE):
+            self.avatarBox.connect('button-press-event', self.on_avatar_click)
+            self.avatarBox.set_tooltip_text(_('Click here to set your avatar'))
         self.avatarBox.add(self.avatar)
-        self.avatarBox.set_tooltip_text(_('Click here to set your avatar'))
         self.avatarBox.set_border_width(4)
 
         self.avatar_path = self.config_dir.get_path("last_avatar")
@@ -143,7 +144,11 @@ class UserPanel(gtk.VBox):
         self.avatarBox.show()
         self.nick.show()
         self.message.show()
-        self.status.show()
+        if self.session.session_has_service(e3.Session.SERVICE_STATUS):
+            self.status.show()
+        else:
+            self.status.hide()
+
         self.search.show()
         if self.userpanel_button:
             self.userpanel_button.show()
@@ -218,8 +223,9 @@ class UserPanel(gtk.VBox):
             self.on_message_change_succeed)
         self.session.signals.media_change_succeed.subscribe(
             self.on_media_change_succeed)
-        self.session.signals.status_change_succeed.subscribe(
-            self.on_status_change_succeed)
+        if self.session.session_has_service(e3.Session.SERVICE_STATUS):
+            self.session.signals.status_change_succeed.subscribe(
+                self.on_status_change_succeed)
         self.session.signals.contact_list_ready.subscribe(
             self.on_contact_list_ready)
         self.session.signals.picture_change_succeed.subscribe(
@@ -235,8 +241,9 @@ class UserPanel(gtk.VBox):
             self.on_message_change_succeed)
         self.session.signals.media_change_succeed.unsubscribe(
             self.on_media_change_succeed)
-        self.session.signals.status_change_succeed.unsubscribe(
-            self.on_status_change_succeed)
+        if self.session.session_has_service(e3.Session.SERVICE_STATUS):
+            self.session.signals.status_change_succeed.unsubscribe(
+                self.on_status_change_succeed)
         self.session.signals.contact_list_ready.unsubscribe(
             self.on_contact_list_ready)
         self.session.signals.picture_change_succeed.unsubscribe(
