@@ -30,7 +30,9 @@ class Window(gtk.Window):
     AUTHOR = 'Mariano Guerra'
     WEBSITE = 'www.emesene.org'
 
-    def __init__(self, cb_on_close, height=410, width=250, posx=100, posy=100):
+    def __init__(self, cb_on_close, height=410, width=250, 
+                 posx=100, posy=100):
+
         gtk.Window.__init__(self)
 
         self.set_location(width, height, posx, posy)
@@ -60,8 +62,8 @@ class Window(gtk.Window):
     def set_icon(self, icon):
         '''set the icon of the window'''
         if utils.file_readable(icon):
-            gtk.Window.set_icon(self, \
-                        utils.safe_gtk_image_load(icon).get_pixbuf())
+            gtk.Window.set_icon(self,
+                                utils.safe_gtk_image_load(icon).get_pixbuf())
 
     def clear(self):
         '''remove the content from the main window'''
@@ -70,9 +72,10 @@ class Window(gtk.Window):
             self.content = None
 
     def go_login(self, callback, on_preferences_changed,
-           config=None, config_dir=None, config_path=None,
-           proxy=None, use_http=None, session_id=None, cancel_clicked=False,
-           no_autologin=False):
+                 config=None, config_dir=None, config_path=None,
+                 proxy=None, use_http=None, session_id=None, 
+                 cancel_clicked=False, no_autologin=False):
+
         '''draw the login window on the main window'''
 
         LoginWindow = extension.get_default('login window')
@@ -122,12 +125,13 @@ class Window(gtk.Window):
         self.connect('key-press-event', self.content._on_key_press)
         self.content.show()
         self.content_type = 'conversation'
-        self.content._set_accels()
+        self.content.set_accels()
 
     def set_location(self, width=0, height=0, posx=None, posy=None):
         """place the window on the given coordinates
         """
-        self.set_default_size(self.set_or_get_width(width), self.set_or_get_height(height))
+        self.set_default_size(self.set_or_get_width(width),
+                              self.set_or_get_height(height))
         self.move(self.set_or_get_posx(posx), self.set_or_get_posy(posy))
 
     def set_or_get_height(self, height=0):
@@ -153,9 +157,8 @@ class Window(gtk.Window):
         width, height = self.get_size()
         return width, height, posx, posy
 
-    def _on_delete_event(self, widget, event):
-        '''call the cb_on_close callback, if the callback return True
-        then dont close the window'''
+    def save_dimensions(self):
+        '''save the window dimensions'''
         width, height, posx, posy = self.get_dimensions()
 
         self.set_or_get_width(width)
@@ -163,12 +166,19 @@ class Window(gtk.Window):
         self.set_or_get_posx(posx)
         self.set_or_get_posy(posy)
 
+    def _on_delete_event(self, widget, event):
+        '''call the cb_on_close callback, if the callback return True
+        then dont close the window'''
+        self.save_dimensions()
         return self.cb_on_close(self.content)
 
     def _on_key_press(self, widget, event):
         '''called when a key is pressed on the window'''
         if self.content_type == 'main':
-            self.content._on_key_press(widget, event)
+            if event.keyval == gtk.keysyms.Escape:
+                self._on_delete_event(None, None)
+            else:
+                self.content._on_key_press(widget, event)
 
     def _on_last_tab_close(self):
         '''do the action when the last tab is closed on a conversation window
@@ -179,11 +189,7 @@ class Window(gtk.Window):
     def hide(self):
         '''override the method to remember the position
         '''
-        width, height, posx, posy = self.get_dimensions()
-        self.set_or_get_width(width)
-        self.set_or_get_height(height)
-        self.set_or_get_posx(posx)
-        self.set_or_get_posy(posy)
+        self.save_dimensions()
         gtk.Window.hide(self)
 
     def show(self):
@@ -192,6 +198,12 @@ class Window(gtk.Window):
         gtk.Window.show(self)
         self.set_location()
 
+    def present(self):
+        '''override the method to set the position
+        '''
+        gtk.Window.present(self)
+        self.set_location()
+
     def _on_window_state_event(self, window, state):
         '''callew when window state is changed
         '''
@@ -201,12 +213,3 @@ class Window(gtk.Window):
         '''return True is window is maximized, False otherwise
         '''
         return self._state & gtk.gdk.WINDOW_STATE_MAXIMIZED == gtk.gdk.WINDOW_STATE_MAXIMIZED
-
-    def iconify(self):
-        ''' yes, we want to iconify the window, really '''
-        gtk.Window.iconify(self)
-
-    def present(self):
-        ''' raise the window '''
-        gtk.Window.present(self)
-
